==> downloads.html?file=gigkalender_v1.2.63_076.zip: gigkalender/admin/tools.php <==
<?php 
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Tools.'</p>';
  if (!loggedIn()) echo $L_003;
  else
  {
    if (!IsUserAdmin()) echo $L_015;
    else
    {
      // Inhalt-Anfang
        if (isset($Form) AND $Form == $L_Button23 AND isset($Tools))
        {
          if ($Tools=="ClearCache")
          {
            clearCache ();
            echo 'Cache cleared!';
          }
          else if ($Tools=="RewriteNewsFeeds")
          {
            include_once ('news/functions.php');
            writeAllFeeds();
            echo 'News Feeds rewritten!';
          }
          //else if ($_POST["Tools"]=="DeletePastGigs") echo 'DeletePastGigs is not implemented yet.';
          //else if ($_POST["Tools"]=="DeleteAllGigs") echo 'DeleteAllGigs is not implemented yet.';
        }
    	  else
        {
          echo '<form method="post" action="index.php?submenue=admin&amp;inhalt=tools">
                  <table summary="Tools">
                    <tr>
                      <td><input type="radio" class="checkbox" name="Tools" value="ClearCache" /></td>
                      <td>Clear Cache</td>
                    </tr>
                    <tr>
                      <td><input type="radio" class="checkbox" name="Tools" value="RewriteNewsFeeds" /></td>
                      <td>Rewrite News Feeds</td>
                    </tr>
                  </table>
                  <br />
                  <fieldset>
                    <input type="hidden" name="http-equiv" value="tools">
                    <input name="Form" type="submit" value="'.$L_Button23.'" class="button" />
                  </fieldset>
                </form>';
        }
      // Inhalt zuende
    }
  }
?>

==> downloads.html?file=gigkalender_v1.2.64.zip: gigkalender/admin/tools.php <==
<?php 
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Tools.'</p>';
  if (!loggedIn()) echo $L_003;
  else
  {
    if (!IsUserAdmin()) echo $L_015;
    else
    {
      // Inhalt-Anfang
        if (isset($Form) AND $Form == $L_Button23 AND isset($Tools))
        {
          if ($Tools=="ClearCache")
          {
            clearCache ();
            echo 'Cache cleared!';
          }
          else if ($Tools=="RewriteNewsFeeds")
          {
            include_once ('news/functions.php');
            writeAllFeeds();
            echo 'News Feeds rewritten!';
          }
        }
    	  else
        {
          echo '<form method="post" action="index.php?submenue=admin&amp;inhalt=tools" accept-charset="UTF-8">
                  <table summary="Tools">
                    <tr>
                      <td><input type="radio" class="checkbox" name="Tools" value="ClearCache" /></td>
                      <td>Clear Cache</td>
                    </tr>
                    <tr>
                      <td><input type="radio" class="checkbox" name="Tools" value="RewriteNewsFeeds" /></td>
                      <td>Rewrite News Feeds</td>
                    </tr>
                  </table>
                  <br />
                  <fieldset>
                    <input type="hidden" name="http-equiv" value="tools">
                    <input name="Form" type="submit" value="'.$L_Button23.'" class="button" />
                  </fieldset>
                </form>';
        }
      // Inhalt zuende
    }
  }
?>
